dispMUA.arDispMUAAllocation["j"] =
{
  "just send a mail" : [ "justsendamail.png" ] ,
  "jetbrains omea" : [ "omea.png" ] ,
  "jfbox webmail" : [ "jfbox_webmail.png" ] ,
  "jobserve-xss" : [ "jobserve.png" , "http://www.jobserve.com/" ] ,
  "jana-server" : [ "jana.png" ] ,
  "jonapot.hu" : [ "netfactory_hu.png" , "http://www.netfactory.hu/" ] ,
  "jobletter " : [ "jobanzeiger.png" , "http://www.jobanzeiger.de/" ] ,
  "jpvmailer" : [ "jpvmailer.png" , "http://www.ottorey.com.ar/jpvmailer.htm" ] ,
  "jaw::mail" : [ "jawmail.png" , "http://www.jawmail.org/" ] ,
  "jet.mail" : [ "jet-mail.png" , "http://www.jetmail.pl/" ] ,
  "javamail" : [ "java.png" , "http://java.sun.com/products/javamail/" ] ,
  "jsvmail" : [ "shuriken_pro.png" ] ,
  "jawmail" : [ "jawmail.png" , "http://www.jawmail.org/" ] ,
  "jamaila" : [ "jamaila.png" , "http://www.javakaffee.de/jamaila/" ] ,
  "jamail3" : [ "jamail.png" ] ,
  "jamail " : [ "jamail.png" ] ,
  "jffnms" : [ "jffnms.png" , "http://www.jffnms.org/" ] ,
  "jbmail" : [ "jbmail.png" ] ,
  "jaring" : [ "jaring.png" , "http://www.jaring.my/" ] ,
  "jmail" : [ "jmail.png" ] ,
  "juno" : [ "juno.png" ] ,
}
